package fitconnect.impl;

import com.nimbusds.jose.jwk.RSAKey;
import fitconnect.api.Sender;
import fitconnect.api.auth.OAuthService;
import fitconnect.api.auth.OAuthToken;
import fitconnect.api.crypto.JWECryptoService;

public class SubmissionSender implements Sender {

    private final OAuthService authService;
    private final JWECryptoService cryptoService;

    public SubmissionSender(final OAuthService authService, JWECryptoService cryptoService){
        this.authService = authService;
        this.cryptoService = cryptoService;
    }

    @Override
    public OAuthToken retrieveAuthenticationToken(String clientId, String clientSecret, String... scope) {
        return authService.authenticate(clientId, clientSecret, scope).orElseThrow();
    }

    @Override
    public String encryptData(RSAKey publicKey, String unencryptedData) {
        return cryptoService.encryptString(publicKey, unencryptedData);
    }

    @Override
    public String encryptAttachment(RSAKey publicKey, byte[] unencryptedAttachment) {
        return cryptoService.encryptBytes(publicKey, unencryptedAttachment);
    }

}
